org.openqa.selenium.server.browserlaunchers (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

## Package org.openqa.selenium.server.browserlaunchers

Provides classes to launch and kill browsers.

See:
Description

Interface Summary
BrowserLauncher | The launcher interface for classes that will start/stop the browser process.
CommandQueueAware |

Class Summary
AbstractBrowserLauncher | Runs the specified command path to start the browser, and kills the process to quit.
AsyncExecute | A handy wrapper around Ant's Execute class that can spawn a process and return the process handle so you can close it yourself later
BrowserInstallation | Encapsulate useful settings of a browser installation discovered with a `BrowserLocator`
BrowserInstallationCache | Cache browser installation corresponding to a spefic browser string and launcher location.
BrowserLauncherFactory | Returns BrowserLaunchers based on simple strings given by the user
BrowserStringParser | Parse a Selenium browser string to extract browserStartCommand if there is one.
DestroyableRuntimeExecutingBrowserLauncher | Runs the specified command path to start the browser, and kills the process to quit.
Firefox2Launcher |
Firefox3Launcher |
FirefoxChromeLauncher |
FirefoxChromeLauncher.ChromeUrlConvert |
FirefoxCustomProfileLauncher |
FirefoxLauncher |
GoogleChromeLauncher | Browser launcher for Google Chrome.
HTABrowserLauncher |
InternetExplorerCustomProxyLauncher |
InternetExplorerLauncher |
KonquerorLauncher |
LauncherUtils | Various static utility functions used to launch browsers
MacProxyManager | Class to manage the proxy server on OS X.
MockBrowserLauncher |
OperaCustomProfileLauncher |
ProxyInjectionFirefoxCustomProfileLauncher | launcher for Firefox under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
ProxyInjectionInternetExplorerCustomProxyLauncher | launcher for IE under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
ProxyInjectionSafariCustomProfileLauncher | launcher for Safari under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
ResourceExtractor |
SafariCustomProfileLauncher |
SafariFileBasedLauncher |
SafariLauncher |
SystemUtils | Helper methods related to runtime operating system
UnixUtils | Handy utilities for managing Unix/Linux processes
WindowsProxyManager |
WindowsUtils |

Enum Summary
LauncherUtils.ProxySetting |

Exception Summary
AsyncExecute.ProcessStillAliveException | Thrown when a process remains alive after attempting to destroy it
InvalidBrowserExecutableException |

## Package org.openqa.selenium.server.browserlaunchers Description

Provides classes to launch and kill browsers.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.